@@ -126,46 +126,29 @@ class AssignmentViewSet(ModelViewSet):
         assignment.remove_candidate(request.user)
         return "You have withdrawn your candidature successfully."
 
-    def get_user_from_request_data(self, request):
-        """
-        Helper method to get a specific user from request data (not the
-        request.user) so that the view self.candidature_other can play with it.
-        """
-        if not isinstance(request.data, dict):
-            raise ValidationError(
-                {
-                    "detail": "Invalid data. Expected dictionary, got {0}.",
-                    "args": [type(request.data)],
-                }
-            )
-        user_str = request.data.get("user", "")
-        try:
-            user_pk = int(user_str)
-        except ValueError:
-            raise ValidationError(
-                {"detail": 'Invalid data. Expected something like {"user": <id>}.'}
-            )
-        try:
-            user = get_user_model().objects.get(pk=user_pk)
-        except get_user_model().DoesNotExist:
-            raise ValidationError(
-                {"detail": "Invalid data. User {0} does not exist.", "args": [user_pk]}
-            )
-        return user
-
     @detail_route(methods=["post", "delete"])
     def candidature_other(self, request, pk=None):
         """
         View to nominate other users (POST) or delete their candidature
         status (DELETE). The client has to send {'user': <id>}.
         """
-        user = self.get_user_from_request_data(request)
+        user_id = request.data.get("user")
+        if not isinstance(user_id, int):
+            raise ValidationError({"detail": "user_id must be an int."})
+
+        try:
+            user = get_user_model().objects.get(pk=user_id)
+        except get_user_model().DoesNotExist:
+            raise ValidationError(
+                {"detail": "Invalid data. User {0} does not exist.", "args": [user_id]}
+            )
+
         assignment = self.get_object()
         if request.method == "POST":
             return self.nominate_other(request, user, assignment)
         else:
             # request.method == 'DELETE'
-            return self.delete_other(request, user, assignment)
+            return self.withdraw_other(request, user, assignment)
 
     def nominate_other(self, request, user, assignment):
         if assignment.phase == assignment.PHASE_FINISHED:
@@ -191,7 +174,7 @@ class AssignmentViewSet(ModelViewSet):
             {"detail": "User {0} was nominated successfully.", "args": [str(user)]}
         )
 
-    def delete_other(self, request, user, assignment):
+    def withdraw_other(self, request, user, assignment):
         # To delete candidature status you have to be a manager.
         if not has_perm(request.user, "assignments.can_manage"):
             self.permission_denied(request)
@@ -285,21 +268,32 @@ class AssignmentPollViewSet(BasePollViewSet):
 
         super().perform_create(serializer)
         poll = AssignmentPoll.objects.get(pk=serializer.data["id"])
-        poll.db_amount_global_abstain = Decimal(0)
+        poll.db_amount_global_yes = Decimal(0)
         poll.db_amount_global_no = Decimal(0)
+        poll.db_amount_global_abstain = Decimal(0)
         poll.save()
 
-    def handle_analog_vote(self, data, poll, user):
+    def handle_analog_vote(self, data, poll):
         for field in ["votesvalid", "votesinvalid", "votescast"]:
             setattr(poll, field, data[field])
 
-        global_no_enabled = (
-            poll.global_no and poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES
+        global_yes_enabled = poll.global_yes and poll.pollmethod in (
+            AssignmentPoll.POLLMETHOD_Y,
+            AssignmentPoll.POLLMETHOD_N,
+        )
+        if global_yes_enabled:
+            poll.amount_global_yes = data.get("amount_global_yes", Decimal(0))
+
+        global_no_enabled = poll.global_no and poll.pollmethod in (
+            AssignmentPoll.POLLMETHOD_Y,
+            AssignmentPoll.POLLMETHOD_N,
         )
         if global_no_enabled:
             poll.amount_global_no = data.get("amount_global_no", Decimal(0))
-        global_abstain_enabled = (
-            poll.global_abstain and poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES
+
+        global_abstain_enabled = poll.global_abstain and poll.pollmethod in (
+            AssignmentPoll.POLLMETHOD_Y,
+            AssignmentPoll.POLLMETHOD_N,
         )
         if global_abstain_enabled:
             poll.amount_global_abstain = data.get("amount_global_abstain", Decimal(0))
@@ -310,55 +304,79 @@ class AssignmentPollViewSet(BasePollViewSet):
         with transaction.atomic():
             for option_id, vote in options_data.items():
                 option = options.get(pk=int(option_id))
-                vote_obj, _ = AssignmentVote.objects.get_or_create(
-                    option=option, value="Y"
-                )
-                vote_obj.weight = vote["Y"]
-                vote_obj.save()
 
-                if poll.pollmethod in (
-                    AssignmentPoll.POLLMETHOD_YN,
-                    AssignmentPoll.POLLMETHOD_YNA,
-                ):
+                if poll.pollmethod == AssignmentPoll.POLLMETHOD_N:
                     vote_obj, _ = AssignmentVote.objects.get_or_create(
                         option=option, value="N"
                     )
                     vote_obj.weight = vote["N"]
                     vote_obj.save()
 
-                if poll.pollmethod == AssignmentPoll.POLLMETHOD_YNA:
+                elif poll.pollmethod in (
+                    AssignmentPoll.POLLMETHOD_Y,
+                    AssignmentPoll.POLLMETHOD_YN,
+                    AssignmentPoll.POLLMETHOD_YNA,
+                ):
+                    # All three methods have a Y
                     vote_obj, _ = AssignmentVote.objects.get_or_create(
-                        option=option, value="A"
+                        option=option, value="Y"
                     )
-                    vote_obj.weight = vote["A"]
+                    vote_obj.weight = vote["Y"]
                     vote_obj.save()
+
+                    if poll.pollmethod in (
+                        AssignmentPoll.POLLMETHOD_YN,
+                        AssignmentPoll.POLLMETHOD_YNA,
+                    ):
+                        vote_obj, _ = AssignmentVote.objects.get_or_create(
+                            option=option, value="N"
+                        )
+                        vote_obj.weight = vote["N"]
+                        vote_obj.save()
+
+                        if poll.pollmethod == AssignmentPoll.POLLMETHOD_YNA:
+                            vote_obj, _ = AssignmentVote.objects.get_or_create(
+                                option=option, value="A"
+                            )
+                            vote_obj.weight = vote["A"]
+                            vote_obj.save()
+
+                else:
+                    raise NotImplementedError(
+                        f"handle_analog_vote not implemented for {poll.pollmethod}"
+                    )
                 inform_changed_data(option)
 
             poll.save()
 
-    def validate_vote_data(self, data, poll, user):
+    def validate_vote_data(self, data, poll):
         """
         Request data:
         analog:
             {
                 "options": {<option_id>: {"Y": <amount>, ["N": <amount>], ["A": <amount>] }},
                 ["votesvalid": <amount>], ["votesinvalid": <amount>], ["votescast": <amount>],
-                ["amount_global_no": <amount>], ["amount_global_abstain": <amount>]
+                ["amount_global_yes": <amount>],
+                ["amount_global_no": <amount>],
+                ["amount_global_abstain": <amount>]
             }
             All amounts are decimals as strings
             required fields per pollmethod:
             - votes: Y
             - YN:    YN
             - YNA:   YNA
+            - N:     N
         named|pseudoanonymous:
             votes:
-                {<option_id>: <amount>} | 'N' | 'A'
+                {<option_id>: <amount>} | 'Y' | 'N' | 'A'
                 - Exactly one of the three options must be given
+                - 'Y' is only valid if poll.global_yes==True
                 - 'N' is only valid if poll.global_no==True
                 - 'A' is only valid if poll.global_abstain==True
                 - amounts must be integer numbers >= 0.
                 - ids should be integers of valid option ids for this poll
                 - amounts must be 0 or 1, if poll.allow_multiple_votes_per_candidate is False
+                - if an option is not given, 0 is assumed
                 - The sum of all amounts must be grater than 0 and <= poll.votes_amount
 
             YN/YNA:
@@ -378,37 +396,56 @@ class AssignmentPollViewSet(BasePollViewSet):
                     raise ValidationError({"detail": "Keys must be int"})
                 if not isinstance(value, dict):
                     raise ValidationError({"detail": "A dict per option is required"})
-                value["Y"] = self.parse_vote_value(value, "Y")
-                if poll.pollmethod in (
-                    AssignmentPoll.POLLMETHOD_YN,
-                    AssignmentPoll.POLLMETHOD_YNA,
-                ):
+                if poll.pollmethod == AssignmentPoll.POLLMETHOD_N:
                     value["N"] = self.parse_vote_value(value, "N")
-                if poll.pollmethod == AssignmentPoll.POLLMETHOD_YNA:
-                    value["A"] = self.parse_vote_value(value, "A")
+                else:
+                    value["Y"] = self.parse_vote_value(value, "Y")
+                    if poll.pollmethod in (
+                        AssignmentPoll.POLLMETHOD_YN,
+                        AssignmentPoll.POLLMETHOD_YNA,
+                    ):
+                        value["N"] = self.parse_vote_value(value, "N")
+                    if poll.pollmethod == AssignmentPoll.POLLMETHOD_YNA:
+                        value["A"] = self.parse_vote_value(value, "A")
 
             for field in ["votesvalid", "votesinvalid", "votescast"]:
                 data[field] = self.parse_vote_value(data, field)
 
-            global_no_enabled = (
-                poll.global_no and poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES
+            global_yes_enabled = poll.global_yes and poll.pollmethod in (
+                AssignmentPoll.POLLMETHOD_Y,
+                AssignmentPoll.POLLMETHOD_N,
             )
-            global_abstain_enabled = (
-                poll.global_abstain
-                and poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES
-            )
-            if "amount_global_abstain" in data and global_abstain_enabled:
-                data["amount_global_abstain"] = self.parse_vote_value(
-                    data, "amount_global_abstain"
+            if "amount_global_yes" in data and global_yes_enabled:
+                data["amount_global_yes"] = self.parse_vote_value(
+                    data, "amount_global_yes"
                 )
+
+            global_no_enabled = poll.global_no and poll.pollmethod in (
+                AssignmentPoll.POLLMETHOD_Y,
+                AssignmentPoll.POLLMETHOD_N,
+            )
             if "amount_global_no" in data and global_no_enabled:
                 data["amount_global_no"] = self.parse_vote_value(
                     data, "amount_global_no"
                 )
 
-        else:
+            global_abstain_enabled = poll.global_abstain and poll.pollmethod in (
+                AssignmentPoll.POLLMETHOD_Y,
+                AssignmentPoll.POLLMETHOD_N,
+            )
+            if "amount_global_abstain" in data and global_abstain_enabled:
+                data["amount_global_abstain"] = self.parse_vote_value(
+                    data, "amount_global_abstain"
+                )
+
+        else:  # non-analog polls
+            if isinstance(data, dict) and len(data) == 0:
+                raise ValidationError({"details": "Empty ballots are not allowed"})
             available_options = poll.get_options()
-            if poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES:
+            if poll.pollmethod in (
+                AssignmentPoll.POLLMETHOD_Y,
+                AssignmentPoll.POLLMETHOD_N,
+            ):
                 if isinstance(data, dict):
                     amount_sum = 0
                     for option_id, amount in data.items():
@@ -419,9 +456,7 @@ class AssignmentPollViewSet(BasePollViewSet):
                                 {"detail": f"Option {option_id} does not exist."}
                             )
                         if not is_int(amount):
-                            raise ValidationError(
-                                {"detail": "Each amounts must be int"}
-                            )
+                            raise ValidationError({"detail": "Each amount must be int"})
                         amount = int(amount)
                         if amount < 0:
                             raise ValidationError(
@@ -443,10 +478,13 @@ class AssignmentPollViewSet(BasePollViewSet):
                                 "args": [poll.votes_amount],
                             }
                         )
+                # return, if there is a global vote, because we dont have to check option presence
+                elif data == "Y" and poll.global_yes:
+                    return
                 elif data == "N" and poll.global_no:
-                    return  # return because we dont have to check option presence
+                    return
                 elif data == "A" and poll.global_abstain:
-                    return  # return because we dont have to check option presence
+                    return
                 else:
                     raise ValidationError({"detail": "invalid data."})
 
@@ -465,23 +503,25 @@ class AssignmentPollViewSet(BasePollViewSet):
                         )
                     if (
                         poll.pollmethod == AssignmentPoll.POLLMETHOD_YNA
-                        and value not in ("Y", "N", "A",)
+                        and value not in ("Y", "N", "A")
                     ):
                         raise ValidationError(
                             {"detail": "Every value must be Y, N or A"}
                         )
                     elif (
                         poll.pollmethod == AssignmentPoll.POLLMETHOD_YN
-                        and value not in ("Y", "N",)
+                        and value not in ("Y", "N")
                     ):
                         raise ValidationError({"detail": "Every value must be Y or N"})
 
             options_data = data
 
-    def create_votes_type_votes(self, data, poll, user):
+    def create_votes_type_votes(self, data, poll, vote_weight, vote_user, request_user):
         """
         Helper function for handle_(named|pseudoanonymous)_vote
         Assumes data is already validated
+        vote_user is the user whose vote is given
+        request_user is the user who gives the vote, may be a delegate
         """
         options = poll.get_options()
         if isinstance(data, dict):
@@ -493,68 +533,90 @@ class AssignmentPollViewSet(BasePollViewSet):
                     continue
                 weight = Decimal(amount)
                 if config["users_activate_vote_weight"]:
-                    weight *= user.vote_weight
+                    weight *= vote_weight
+                value = "Y"  # POLLMETHOD_Y
+                if poll.pollmethod == AssignmentPoll.POLLMETHOD_N:
+                    value = "N"
                 vote = AssignmentVote.objects.create(
-                    option=option, user=user, weight=weight, value="Y"
+                    option=option,
+                    user=vote_user,
+                    delegated_user=request_user,
+                    weight=weight,
+                    value=value,
                 )
                 inform_changed_data(vote, no_delete_on_restriction=True)
         else:  # global_no or global_abstain
             option = options[0]
-            weight = (
-                user.vote_weight if config["users_activate_vote_weight"] else Decimal(1)
-            )
+            weight = vote_weight if config["users_activate_vote_weight"] else Decimal(1)
             vote = AssignmentVote.objects.create(
-                option=option, user=user, weight=weight, value=data
+                option=option,
+                user=vote_user,
+                delegated_user=request_user,
+                weight=weight,
+                value=data,
             )
             inform_changed_data(vote, no_delete_on_restriction=True)
             inform_changed_data(option)
             inform_changed_data(poll)
 
-        poll.voted.add(user)
-
-    def create_votes_types_yn_yna(self, data, poll, check_user, vote_user):
+    def create_votes_types_yn_yna(
+        self, data, poll, vote_weight, vote_user, request_user
+    ):
         """
-        check_user is used for the voted-array and weight of the vote,
-        vote_user is the one put into the vote
+        Helper function for handle_(named|pseudoanonymous)_vote
+        Assumes data is already validated
+        vote_user is the user whose vote is given
+        request_user is the user who gives the vote, may be a delegate
         """
         options = poll.get_options()
-        weight = (
-            check_user.vote_weight
-            if config["users_activate_vote_weight"]
-            else Decimal(1)
-        )
+        weight = vote_weight if config["users_activate_vote_weight"] else Decimal(1)
         for option_id, result in data.items():
             option = options.get(pk=option_id)
             vote = AssignmentVote.objects.create(
-                option=option, user=vote_user, value=result, weight=weight,
+                option=option,
+                user=vote_user,
+                delegated_user=request_user,
+                value=result,
+                weight=weight,
             )
             inform_changed_data(vote, no_delete_on_restriction=True)
             inform_changed_data(option, no_delete_on_restriction=True)
 
-        poll.voted.add(check_user)
-
     def add_user_to_voted_array(self, user, poll):
         VotedModel = AssignmentPoll.voted.through
         VotedModel.objects.create(assignmentpoll=poll, user=user)
 
-    def handle_named_vote(self, data, poll, user):
-        if poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES:
-            self.create_votes_type_votes(data, poll, user)
+    def handle_named_vote(self, data, poll, vote_user, request_user):
+        if poll.pollmethod in (
+            AssignmentPoll.POLLMETHOD_Y,
+            AssignmentPoll.POLLMETHOD_N,
+        ):
+            self.create_votes_type_votes(
+                data, poll, vote_user.vote_weight, vote_user, request_user
+            )
         elif poll.pollmethod in (
             AssignmentPoll.POLLMETHOD_YN,
             AssignmentPoll.POLLMETHOD_YNA,
         ):
-            self.create_votes_types_yn_yna(data, poll, user, user)
+            self.create_votes_types_yn_yna(
+                data, poll, vote_user.vote_weight, vote_user, request_user
+            )
+        else:
+            raise NotImplementedError(f"The method {poll.pollmethod} is not supported!")
 
     def handle_pseudoanonymous_vote(self, data, poll, user):
-        if poll.pollmethod == AssignmentPoll.POLLMETHOD_VOTES:
-            self.create_votes_type_votes(data, poll, user)
-
+        if poll.pollmethod in (
+            AssignmentPoll.POLLMETHOD_Y,
+            AssignmentPoll.POLLMETHOD_N,
+        ):
+            self.create_votes_type_votes(data, poll, user.vote_weight, None, None)
         elif poll.pollmethod in (
             AssignmentPoll.POLLMETHOD_YN,
             AssignmentPoll.POLLMETHOD_YNA,
         ):
-            self.create_votes_types_yn_yna(data, poll, user, None)
+            self.create_votes_types_yn_yna(data, poll, user.vote_weight, None, None)
+        else:
+            raise NotImplementedError(f"The method {poll.pollmethod} is not supported!")
 
     def convert_option_data(self, poll, data):
         poll_options = poll.get_options()
