@@ -193,7 +193,7 @@ class Motion(RESTModelMixin, AgendaItemWithListOfSpeakersMixin, models.Model):
     """
 
     motion_block = models.ForeignKey(
-        "MotionBlock", on_delete=SET_NULL_AND_AUTOUPDATE, null=True, blank=True,
+        "MotionBlock", on_delete=SET_NULL_AND_AUTOUPDATE, null=True, blank=True
     )
     """
     ForeignKey to one block of motions.
