@@ -1,17 +1,21 @@
-from typing import Dict, Optional
-
 import jsonschema
 from django.db import transaction
 
+from openslides.poll.serializers import (
+    BASE_OPTION_FIELDS,
+    BASE_POLL_FIELDS,
+    BASE_VOTE_FIELDS,
+    BaseOptionSerializer,
+    BasePollSerializer,
+    BaseVoteSerializer,
+)
+
 from ..core.config import config
-from ..poll.serializers import default_votes_validator
 from ..utils.auth import get_group_model, has_perm
 from ..utils.autoupdate import inform_changed_data
 from ..utils.rest_api import (
     BooleanField,
     CharField,
-    DecimalField,
-    DictField,
     Field,
     IdPrimaryKeyRelatedField,
     IntegerField,
@@ -20,7 +24,7 @@ from ..utils.rest_api import (
     SerializerMethodField,
     ValidationError,
 )
-from ..utils.validate import validate_html
+from ..utils.validate import validate_html_strict
 from .models import (
     Category,
     Motion,
@@ -28,7 +32,9 @@ from .models import (
     MotionChangeRecommendation,
     MotionComment,
     MotionCommentSection,
+    MotionOption,
     MotionPoll,
+    MotionVote,
     State,
     StatuteParagraph,
     Submitter,
@@ -77,6 +83,7 @@ class MotionBlockSerializer(ModelSerializer):
         write_only=True, required=False, min_value=1, max_value=3, allow_null=True
     )
     agenda_parent_id = IntegerField(write_only=True, required=False, min_value=1)
+    motions_id = SerializerMethodField()
 
     class Meta:
         model = MotionBlock
@@ -89,8 +96,12 @@ class MotionBlockSerializer(ModelSerializer):
             "agenda_type",
             "agenda_parent_id",
             "internal",
+            "motions_id",
         )
 
+    def get_motions_id(self, block):
+        return [motion.id for motion in block.motion_set.all()]
+
     def create(self, validated_data):
         """
         Customized create method. Set information about related agenda item
@@ -220,116 +231,44 @@ class AmendmentParagraphsJSONSerializerField(Field):
         return data
 
 
-class MotionPollSerializer(ModelSerializer):
+class MotionVoteSerializer(BaseVoteSerializer):
+    class Meta:
+        model = MotionVote
+        fields = BASE_VOTE_FIELDS
+        read_only_fields = BASE_VOTE_FIELDS
+
+
+class MotionOptionSerializer(BaseOptionSerializer):
+    class Meta:
+        model = MotionOption
+        fields = BASE_OPTION_FIELDS
+        read_only_fields = BASE_OPTION_FIELDS
+
+
+class MotionPollSerializer(BasePollSerializer):
     """
     Serializer for motion.models.MotionPoll objects.
     """
 
-    yes = SerializerMethodField()
-    no = SerializerMethodField()
-    abstain = SerializerMethodField()
-    votes = DictField(
-        child=DecimalField(
-            max_digits=15, decimal_places=6, min_value=-2, allow_null=True
-        ),
-        write_only=True,
-    )
-    has_votes = SerializerMethodField()
-
     class Meta:
         model = MotionPoll
-        fields = (
-            "id",
-            "motion",
-            "yes",
-            "no",
-            "abstain",
-            "votesvalid",
-            "votesinvalid",
-            "votescast",
-            "votes",
-            "has_votes",
-        )
-        validators = (default_votes_validator,)
+        fields = ("motion", "pollmethod") + BASE_POLL_FIELDS
+        read_only_fields = ("state",)
 
-    def __init__(self, *args, **kwargs):
-        # The following dictionary is just a cache for several votes.
-        self._votes_dicts: Dict[int, Dict[int, int]] = {}
-        super().__init__(*args, **kwargs)
-
-    def get_yes(self, obj):
-        try:
-            result: Optional[str] = str(self.get_votes_dict(obj)["Yes"])
-        except KeyError:
-            result = None
-        return result
-
-    def get_no(self, obj):
-        try:
-            result: Optional[str] = str(self.get_votes_dict(obj)["No"])
-        except KeyError:
-            result = None
-        return result
-
-    def get_abstain(self, obj):
-        try:
-            result: Optional[str] = str(self.get_votes_dict(obj)["Abstain"])
-        except KeyError:
-            result = None
-        return result
-
-    def get_votes_dict(self, obj):
-        try:
-            votes_dict = self._votes_dicts[obj.pk]
-        except KeyError:
-            votes_dict = self._votes_dicts[obj.pk] = {}
-            for vote in obj.get_votes():
-                votes_dict[vote.value] = vote.weight
-        return votes_dict
-
-    def get_has_votes(self, obj):
-        """
-        Returns True if this poll has some votes.
-        """
-        return obj.has_votes()
-
-    @transaction.atomic
     def update(self, instance, validated_data):
-        """
-        Customized update method for polls. To update votes use the write
-        only field 'votes'.
+        """ Prevent updating the motion """
+        validated_data.pop("motion", None)
+        return super().update(instance, validated_data)
 
-        Example data:
-
-            "votes": {"Yes": 10, "No": 4, "Abstain": -2}
-        """
-        # Update votes.
-        votes = validated_data.get("votes")
-        if votes:
-            if len(votes) != len(instance.get_vote_values()):
-                raise ValidationError(
-                    {
-                        "detail": "You have to submit data for {0} vote values.",
-                        "args": [len(instance.get_vote_values())],
-                    }
-                )
-            for vote_value in votes.keys():
-                if vote_value not in instance.get_vote_values():
-                    raise ValidationError(
-                        {"detail": "Vote value {0} is invalid.", "args": [vote_value]}
-                    )
-            instance.set_vote_objects_with_values(
-                instance.get_options().get(), votes, skip_autoupdate=True
-            )
-
-        # Update remaining writeable fields.
-        instance.votesvalid = validated_data.get("votesvalid", instance.votesvalid)
-        instance.votesinvalid = validated_data.get(
-            "votesinvalid", instance.votesinvalid
-        )
-        instance.votescast = validated_data.get("votescast", instance.votescast)
-        instance.save()
-        return instance
+    def norm_100_percent_base_to_pollmethod(
+        self, onehundred_percent_base, pollmethod, old_100_percent_base=None
+    ):
+        if (
+            pollmethod == MotionPoll.POLLMETHOD_YN
+            and onehundred_percent_base == MotionPoll.PERCENT_BASE_YNA
+        ):
+            return MotionPoll.PERCENT_BASE_YN
+        return None
 
 
 class MotionChangeRecommendationSerializer(ModelSerializer):
@@ -358,7 +297,7 @@ class MotionChangeRecommendationSerializer(ModelSerializer):
     def validate(self, data):
         # Change recommendations for titles are stored as plain-text, thus they don't need to be html-escaped
         if "text" in data and not self.is_title_cr(data):
-            data["text"] = validate_html(data["text"])
+            data["text"] = validate_html_strict(data["text"])
         return data
 
 
@@ -418,7 +357,6 @@ class MotionSerializer(ModelSerializer):
     """
 
     comments = MotionCommentSerializer(many=True, read_only=True)
-    polls = MotionPollSerializer(many=True, read_only=True)
     modified_final_version = CharField(allow_blank=True, required=False)
     reason = CharField(allow_blank=True, required=False)
     state_restriction = SerializerMethodField()
@@ -438,6 +376,7 @@ class MotionSerializer(ModelSerializer):
     agenda_parent_id = IntegerField(write_only=True, required=False, min_value=1)
     submitters = SubmitterSerializer(many=True, read_only=True)
     change_recommendations = IdPrimaryKeyRelatedField(many=True, read_only=True)
+    amendments_id = SerializerMethodField()
 
     class Meta:
         model = Motion
@@ -466,7 +405,6 @@ class MotionSerializer(ModelSerializer):
             "recommendation_extension",
             "tags",
             "attachments",
-            "polls",
             "agenda_item_id",
             "list_of_speakers_id",
             "agenda_create",
@@ -477,31 +415,36 @@ class MotionSerializer(ModelSerializer):
             "created",
             "last_modified",
             "change_recommendations",
+            "amendments_id",
         )
         read_only_fields = (
             "state",
             "recommendation",
             "weight",
             "category_weight",
+            "amendments_id",
         )  # Some other fields are also read_only. See definitions above.
 
+    def get_amendments_id(self, motion):
+        return [amendment.id for amendment in motion.amendments.all()]
+
     def validate(self, data):
         if "text" in data:
-            data["text"] = validate_html(data["text"])
+            data["text"] = validate_html_strict(data["text"])
 
         if "modified_final_version" in data:
-            data["modified_final_version"] = validate_html(
+            data["modified_final_version"] = validate_html_strict(
                 data["modified_final_version"]
             )
 
         if "reason" in data:
-            data["reason"] = validate_html(data["reason"])
+            data["reason"] = validate_html_strict(data["reason"])
 
         # The motion text is only needed, if it is not a paragraph based amendment.
         if data.get("amendment_paragraphs") is not None:
             data["amendment_paragraphs"] = list(
                 map(
-                    lambda entry: validate_html(entry)
+                    lambda entry: validate_html_strict(entry)
                     if isinstance(entry, str)
                     else None,
                     data["amendment_paragraphs"],
@@ -556,6 +499,12 @@ class MotionSerializer(ModelSerializer):
         motion.supporters.add(*validated_data.get("supporters", []))
         motion.attachments.add(*validated_data.get("attachments", []))
         motion.tags.add(*validated_data.get("tags", []))
+
+        if motion.parent:
+            inform_changed_data(motion.parent)
+        if motion.motion_block:
+            inform_changed_data(motion.motion_block)
+
         return motion
 
     @transaction.atomic
@@ -576,6 +525,8 @@ class MotionSerializer(ModelSerializer):
             if validated_data.get("category") is not None
             else None
         )
+        old_block = motion.motion_block
+        new_block = validated_data.get("motion_block")
 
         result = super().update(motion, validated_data)
 
@@ -591,6 +542,12 @@ class MotionSerializer(ModelSerializer):
 
         inform_changed_data(motion)
 
+        if new_block != old_block:
+            if new_block:
+                inform_changed_data(new_block)
+            if old_block:
+                inform_changed_data(old_block)
+
         return result
 
     def get_state_restriction(self, motion):
