@@ -1,24 +1,28 @@
 from django.db import models
 
+from openslides.utils.manager import BaseManager
+
 from ..agenda.mixins import AgendaItemWithListOfSpeakersMixin
 from ..mediafiles.models import Mediafile
 from ..utils.models import RESTModelMixin
 from .access_permissions import TopicAccessPermissions
 
 
-class TopicManager(models.Manager):
+class TopicManager(BaseManager):
     """
-    Customized model manager to support our get_full_queryset method.
+    Customized model manager to support our get_prefetched_queryset method.
     """
 
-    def get_full_queryset(self):
+    def get_prefetched_queryset(self, *args, **kwargs):
         """
         Returns the normal queryset with all topics. In the background all
         attachments and the related agenda item are prefetched from the
         database.
         """
-        return self.get_queryset().prefetch_related(
-            "attachments", "lists_of_speakers", "agenda_items"
+        return (
+            super()
+            .get_prefetched_queryset(*args, **kwargs)
+            .prefetch_related("attachments", "lists_of_speakers", "agenda_items")
         )
 
 
