@@ -2,7 +2,7 @@ from django.conf import settings
 from django.conf.urls import include, url
 from django.views.generic import RedirectView
 
-from openslides.mediafiles.views import protected_serve
+from openslides.mediafiles.views import check_serve, protected_serve
 from openslides.utils.rest_api import router
 
 from .core import views as core_views
@@ -15,6 +15,7 @@ urlpatterns = [
         protected_serve,
         {"document_root": settings.MEDIA_ROOT},
     ),
+    url(r"^check-media/(?P<path>.*)$", check_serve),
     # URLs for the rest system, redirect /rest to /rest/
     url(r"^rest$", RedirectView.as_view(url="/rest/", permanent=True)),
     url(r"^rest/", include(router.urls)),
