@@ -23,6 +23,7 @@ from django.utils.encoding import force_bytes, force_text
 from django.utils.http import urlsafe_base64_decode, urlsafe_base64_encode
 
 from openslides.saml import SAML_ENABLED
+from openslides.utils import logging
 
 from ..core.config import config
 from ..core.signals import permission_change
@@ -35,6 +36,7 @@ from ..utils.auth import (
 from ..utils.autoupdate import AutoupdateElement, inform_changed_data, inform_elements
 from ..utils.cache import element_cache
 from ..utils.rest_api import (
+    APIException,
     ModelViewSet,
     Response,
     SimpleMetadata,
@@ -55,7 +57,23 @@ from .serializers import GroupSerializer, PermissionRelatedField
 from .user_backend import user_backend_manager
 
 
-# Viewsets for the REST API
+demo_mode_users = getattr(settings, "DEMO_USERS", None)
+is_demo_mode = isinstance(demo_mode_users, list) and len(demo_mode_users) > 0
+logger = logging.getLogger(__name__)
+if is_demo_mode:
+    logger.info("OpenSlides started in demo mode. Some features are unavailable.")
+
+
+def assertNoDemoAndAdmin(user_ids):
+    if isinstance(user_ids, int):
+        user_ids = [user_ids]
+    if is_demo_mode and any(user_id in demo_mode_users for user_id in user_ids):
+        raise ValidationError({"detail": "Not allowed in demo mode"})
+
+
+def assertNoDemo():
+    if is_demo_mode:
+        raise ValidationError({"detail": "Not allowed in demo mode"})
 
 
 class UserViewSet(ModelViewSet):
@@ -117,6 +135,7 @@ class UserViewSet(ModelViewSet):
         wants to update himself or is manager.
         """
         user = self.get_object()
+        assertNoDemoAndAdmin(user.id)
         # Check permissions.
         if (
             has_perm(self.request.user, "users.can_see_name")
@@ -156,15 +175,84 @@ class UserViewSet(ModelViewSet):
         ):
             request.data["username"] = user.username
 
+        # check that no chains are created with vote delegation
+        delegate_id = request.data.get("vote_delegated_to_id")
+        if delegate_id:
+            try:
+                delegate = User.objects.get(id=delegate_id)
+            except User.DoesNotExist:
+                raise ValidationError(
+                    {
+                        "detail": f"Vote delegation: The user with id {delegate_id} does not exist"
+                    }
+                )
+
+            self.assert_no_self_delegation(user, [delegate_id])
+            self.assert_vote_not_delegated(delegate)
+            self.assert_has_no_delegated_votes(user)
+
+            inform_changed_data(delegate)
+            if user.vote_delegated_to:
+                inform_changed_data(user.vote_delegated_to)
+
+        # handle delegated_from field seperately since its a SerializerMethodField
+        new_delegation_ids = request.data.get("vote_delegated_from_users_id")
+        if "vote_delegated_from_users_id" in request.data:
+            del request.data["vote_delegated_from_users_id"]
+
         response = super().update(request, *args, **kwargs)
+
+        # after rest of the request succeeded, handle delegation changes
+        if new_delegation_ids:
+            self.assert_no_self_delegation(user, new_delegation_ids)
+            self.assert_vote_not_delegated(user)
+
+            for id in new_delegation_ids:
+                delegation_user = User.objects.get(id=id)
+                self.assert_has_no_delegated_votes(delegation_user)
+                delegation_user.vote_delegated_to = user
+                delegation_user.save()
+
+        delegations_to_remove = user.vote_delegated_from_users.exclude(
+            id__in=(new_delegation_ids or [])
+        )
+        for old_delegation_user in delegations_to_remove:
+            old_delegation_user.vote_delegated_to = None
+            old_delegation_user.save()
+
+        # if only delegated_from was changed, we need an autoupdate for the operator
+        if new_delegation_ids or delegations_to_remove:
+            inform_changed_data(user)
+
         return response
 
+    def assert_vote_not_delegated(self, user):
+        if user.vote_delegated_to:
+            raise ValidationError(
+                {
+                    "detail": "You cannot delegate a vote to a user who has already delegated his vote."
+                }
+            )
+
+    def assert_has_no_delegated_votes(self, user):
+        if user.vote_delegated_from_users and len(user.vote_delegated_from_users.all()):
+            raise ValidationError(
+                {
+                    "detail": "You cannot delegate a delegation of vote to another user (cascading not allowed)."
+                }
+            )
+
+    def assert_no_self_delegation(self, user, delegate_ids):
+        if user.id in delegate_ids:
+            raise ValidationError({"detail": "You cannot delegate a vote to yourself."})
+
     def destroy(self, request, *args, **kwargs):
         """
         Customized view endpoint to delete an user.
 
         Ensures that no one can delete himself.
         """
+        assertNoDemo()
         instance = self.get_object()
         if instance == self.request.user:
             raise ValidationError({"detail": "You can not delete yourself."})
@@ -178,6 +266,7 @@ class UserViewSet(ModelViewSet):
         Expected data: { pasword: <the new password> }
         """
         user = self.get_object()
+        assertNoDemoAndAdmin(user.id)
         if user.auth_type != "default":
             raise ValidationError(
                 {
@@ -204,6 +293,7 @@ class UserViewSet(ModelViewSet):
         and the default password will be set to the new generated passwords.
         Expected data: { user_ids: <list of ids> }
         """
+        assertNoDemo()
         ids = request.data.get("user_ids")
         self.assert_list_of_ints(ids)
 
@@ -223,6 +313,7 @@ class UserViewSet(ModelViewSet):
         request user is excluded.
         Expected data: { user_ids: <list of ids> }
         """
+        assertNoDemo()
         ids = request.data.get("user_ids")
         self.assert_list_of_ints(ids)
 
@@ -259,10 +350,12 @@ class UserViewSet(ModelViewSet):
           field: 'is_active' | 'is_present' | 'is_committee'
           value: True|False
         }
-        """
 
+        Is_active and is_committee will not be settable for non-default auth type users.
+        """
         ids = request.data.get("user_ids")
         self.assert_list_of_ints(ids)
+        assertNoDemoAndAdmin(ids)
 
         field = request.data.get("field")
         if field not in ("is_active", "is_present", "is_committee"):
@@ -271,9 +364,12 @@ class UserViewSet(ModelViewSet):
         if not isinstance(value, bool):
             raise ValidationError({"detail": "value must be true or false"})
 
-        users = User.objects.filter(auth_type="default").filter(pk__in=ids)
+        users = User.objects.filter(pk__in=ids)
+        if field != "is_present":
+            users = users.filter(auth_type="default")
         if field == "is_active":
             users = users.exclude(pk=request.user.id)
+
         for user in users:
             setattr(user, field, value)
             user.save()
@@ -293,6 +389,7 @@ class UserViewSet(ModelViewSet):
         """
         user_ids = request.data.get("user_ids")
         self.assert_list_of_ints(user_ids)
+        assertNoDemoAndAdmin(user_ids)
         group_ids = request.data.get("group_ids")
         self.assert_list_of_ints(group_ids, ids_name="groups_id")
 
@@ -300,7 +397,7 @@ class UserViewSet(ModelViewSet):
         if action not in ("add", "remove"):
             raise ValidationError({"detail": "The action must be add or remove"})
 
-        users = self.bulk_get_users(request, user_ids)
+        users = self.bulk_get_users(request, user_ids, auth_type=None)
         groups = list(Group.objects.filter(pk__in=group_ids))
 
         for user in users:
@@ -318,6 +415,7 @@ class UserViewSet(ModelViewSet):
         Deletes many users. The request user will be excluded. Expected data:
         { user_ids: <list of ids> }
         """
+        assertNoDemo()
         ids = request.data.get("user_ids")
         self.assert_list_of_ints(ids)
 
@@ -367,6 +465,7 @@ class UserViewSet(ModelViewSet):
             data = serializer.prepare_password(serializer.data)
             groups = data["groups_id"]
             del data["groups_id"]
+            del data["vote_delegated_from_users_id"]
 
             db_user = User(**data)
             try:
@@ -396,6 +495,7 @@ class UserViewSet(ModelViewSet):
         Endpoint to send invitation emails to all given users (by id). Returns the
         number of emails send.
         """
+        assertNoDemo()
         user_ids = request.data.get("user_ids")
         self.assert_list_of_ints(user_ids)
         # Get subject and body from the response. Do not use the config values
@@ -421,7 +521,11 @@ class UserViewSet(ModelViewSet):
                 }
             )
         except smtplib.SMTPException as err:
-            raise ValidationError({"detail": f"{err.errno}: {err.strerror}"})
+            if err.errno and err.strerror:
+                detail = f"{err.errno}: {err.strerror}"
+            else:
+                detail = str(err)
+            raise ValidationError({"detail": detail})
 
         success_users = []
         user_pks_without_email = []
@@ -559,6 +663,7 @@ class GroupViewSet(ModelViewSet):
 
         # Delete the group
         self.perform_destroy(instance)
+        config.remove_group_id_from_all_group_configs(instance.id)
 
         # Get the updated user data from the DB.
         affected_users = User.objects.filter(pk__in=affected_users_ids)
@@ -753,6 +858,9 @@ class WhoAmIDataView(APIView):
             user_full_data = async_to_sync(element_cache.get_element_data)(
                 self.request.user.get_collection_string(), user_id
             )
+            if user_full_data is None:
+                raise APIException(f"Could not find user {user_id}", 500)
+
             auth_type = user_full_data["auth_type"]
             user_data = async_to_sync(element_cache.restrict_element_data)(
                 user_full_data, self.request.user.get_collection_string(), user_id
@@ -881,6 +989,7 @@ class SetPasswordView(APIView):
             or user.auth_type != "default"
         ):
             self.permission_denied(request)
+        assertNoDemoAndAdmin(user.id)
         if user.check_password(request.data["old_password"]):
             try:
                 validate_password(request.data.get("new_password"), user=user)
