@@ -8,7 +8,11 @@ from django.core.exceptions import ImproperlyConfigured
 from typing_extensions import Protocol
 
 from . import logging
-from .redis import use_redis
+from .redis import (
+    read_only_redis_amount_replicas,
+    read_only_redis_wait_timeout,
+    use_redis,
+)
 from .schema_version import SchemaVersion
 from .utils import split_element_id, str_dict_to_bytes
 
@@ -16,7 +20,7 @@ from .utils import split_element_id, str_dict_to_bytes
 logger = logging.getLogger(__name__)
 
 if use_redis:
-    from .redis import get_connection, aioredis
+    from .redis import aioredis, get_connection
 
 
 class CacheReset(Exception):
@@ -44,12 +48,18 @@ class ElementCacheProvider(Protocol):
     ) -> None:
         ...
 
+    async def add_to_full_data(self, data: Dict[str, str]) -> None:
+        ...
+
     async def data_exists(self) -> bool:
         ...
 
     async def get_all_data(self) -> Dict[bytes, bytes]:
         ...
 
+    async def get_all_data_with_max_change_id(self) -> Tuple[int, Dict[bytes, bytes]]:
+        ...
+
     async def get_collection_data(self, collection: str) -> Dict[int, bytes]:
         ...
 
@@ -62,8 +72,8 @@ class ElementCacheProvider(Protocol):
         ...
 
     async def get_data_since(
-        self, change_id: int, max_change_id: int = -1
-    ) -> Tuple[Dict[str, List[bytes]], List[str]]:
+        self, change_id: int
+    ) -> Tuple[int, Dict[str, List[bytes]], List[str]]:
         ...
 
     async def get_current_change_id(self) -> int:
@@ -130,6 +140,24 @@ class RedisCacheProvider:
             False,
         ),
         "get_all_data": ("return redis.call('hgetall', KEYS[1])", True),
+        "get_all_data_with_max_change_id": (
+            """
+            local tmp = redis.call('zrevrangebyscore', KEYS[2], '+inf', '-inf', 'WITHSCORES', 'LIMIT', 0, 1)
+            local max_change_id
+            if next(tmp) == nil then
+                -- The key does not exist
+                return redis.error_reply("cache_reset")
+            else
+                max_change_id = tmp[2]
+            end
+
+            local all_data = redis.call('hgetall', KEYS[1])
+            table.insert(all_data, 'max_change_id')
+            table.insert(all_data, max_change_id)
+            return all_data
+            """,
+            True,
+        ),
         "get_collection_data": (
             """
             local cursor = 0
@@ -147,6 +175,12 @@ class RedisCacheProvider:
         ),
         "get_element_data": ("return redis.call('hget', KEYS[1], ARGV[1])", True),
         "add_changed_elements": (
+            # KEYS[1]: full data cache key
+            # KEYS[2]: change id cache key
+            # ARGV[1]: amount changed elements
+            # ARGV[2]: amount deleted elements
+            # ARGV[3..(ARGV[1]+2)]: changed_elements (element_id, element, element_id, element, ...)
+            # ARGV[(3+ARGV[1])..(ARGV[1]+ARGV[2]+2)]: deleted_elements (element_id, element_id, ...)
             """
             -- Generate a new change_id
             local tmp = redis.call('zrevrangebyscore', KEYS[2], '+inf', '-inf', 'WITHSCORES', 'LIMIT', 0, 1)
@@ -161,36 +195,83 @@ class RedisCacheProvider:
             local nc = tonumber(ARGV[1])
             local nd = tonumber(ARGV[2])
 
-            local i, max
-            -- Add changed_elements to the cache and sorted set (the first of the pairs)
+            local i, max, batch_counter
+            local change_id_data -- change_id, element_id, change_id, element_id, ...
+
+            -- Add changed_elements to the cache and sorted set using batches of 1000
+            -- values in unpack() (see #5386)
+            local elements -- element_id, element, element_id, element, ...
             if (nc > 0) then
-                max = 1 + nc
-                redis.call('hmset', KEYS[1], unpack(ARGV, 3, max + 1))
-                for i = 3, max, 2 do
-                    redis.call('zadd', KEYS[2], change_id, ARGV[i])
+                i = 3
+                max = 3 + nc
+                while (i < max) do
+                    change_id_data = {}
+                    elements = {}
+                    batch_counter = 1
+                    while (i < max and batch_counter <= 1000) do
+                        change_id_data[batch_counter] = change_id
+                        change_id_data[batch_counter + 1] = ARGV[i]
+                        elements[batch_counter] = ARGV[i]
+                        elements[batch_counter + 1] = ARGV[i + 1]
+                        batch_counter = batch_counter + 2
+                        i = i + 2
+                    end
+                    if (#change_id_data > 0) then -- so is #elements > 0
+                        redis.call('hmset', KEYS[1], unpack(elements))
+                        redis.call('zadd', KEYS[2], unpack(change_id_data))
+                    end
                 end
             end
 
             -- Delete deleted_element_ids and add them to sorted set
+            local element_ids -- element_id, element_id, ...
+            local element_ids_counter
             if (nd > 0) then
-                max = 2 + nc + nd
-                redis.call('hdel', KEYS[1], unpack(ARGV, 3 + nc, max))
-                for i = 3 + nc, max, 1 do
-                    redis.call('zadd', KEYS[2], change_id, ARGV[i])
+                i = 3 + nc
+                max = 3 + nc + nd
+                while (i < max) do
+                    change_id_data = {}
+                    element_ids = {}
+                    batch_counter = 1
+                    element_ids_counter = 1
+                    while (i < max and batch_counter <= 1000) do
+                        change_id_data[batch_counter] = change_id
+                        change_id_data[batch_counter + 1] = ARGV[i]
+                        element_ids[element_ids_counter] = ARGV[i]
+                        batch_counter = batch_counter + 2
+                        element_ids_counter = element_ids_counter + 1
+                        i = i + 1
+                    end
+                    if (#change_id_data > 0) then -- so is #element_ids > 0
+                        redis.call('hdel', KEYS[1], unpack(element_ids))
+                        redis.call('zadd', KEYS[2], unpack(change_id_data))
+                    end
                 end
             end
-
             return change_id
             """,
             True,
         ),
         "get_data_since": (
             """
-            -- Get change ids of changed elements
-            local element_ids = redis.call('zrangebyscore', KEYS[2], ARGV[1], ARGV[2])
+            -- get max change id
+            local tmp = redis.call('zrevrangebyscore', KEYS[2], '+inf', '-inf', 'WITHSCORES', 'LIMIT', 0, 1)
+            local max_change_id
+            if next(tmp) == nil then
+                -- The key does not exist
+                return redis.error_reply("cache_reset")
+            else
+                max_change_id = tmp[2]
+            end
 
-            -- Save elements in array. Rotate element_id and element_json
+            -- Get change ids of changed elements
+            local element_ids = redis.call('zrangebyscore', KEYS[2], ARGV[1], max_change_id)
+
+            -- Save elements in array. First is the max_change_id with the key "max_change_id"
+            -- Than rotate element_id and element_json. This is ocnverted into a dict in python code.
             local elements = {}
+            table.insert(elements, 'max_change_id')
+            table.insert(elements, max_change_id)
             for _, element_id in pairs(element_ids) do
               table.insert(elements, element_id)
               table.insert(elements, redis.call('hget', KEYS[1], element_id))
@@ -252,6 +333,10 @@ class RedisCacheProvider:
             )
             await tr.execute()
 
+    async def add_to_full_data(self, data: Dict[str, str]) -> None:
+        async with get_connection() as redis:
+            await redis.hmset_dict(self.full_data_cache_key, data)
+
     async def data_exists(self) -> bool:
         """
         Returns True, when there is data in the cache.
@@ -269,9 +354,25 @@ class RedisCacheProvider:
         Returns all data from the full_data_cache in a mapping from element_id to the element.
         """
         return await aioredis.util.wait_make_dict(
-            self.eval("get_all_data", [self.full_data_cache_key], read_only=True)
+            self.eval("get_all_data", keys=[self.full_data_cache_key], read_only=True)
         )
 
+    @ensure_cache_wrapper()
+    async def get_all_data_with_max_change_id(self) -> Tuple[int, Dict[bytes, bytes]]:
+        """
+        Returns all data from the full_data_cache in a mapping from element_id to the element and
+        the max change id.
+        """
+        all_data = await aioredis.util.wait_make_dict(
+            self.eval(
+                "get_all_data_with_max_change_id",
+                keys=[self.full_data_cache_key, self.change_id_cache_key],
+                read_only=True,
+            )
+        )
+        max_change_id = int(all_data.pop(b"max_change_id"))
+        return max_change_id, all_data
+
     @ensure_cache_wrapper()
     async def get_collection_data(self, collection: str) -> Dict[int, bytes]:
         """
@@ -325,20 +426,18 @@ class RedisCacheProvider:
 
     @ensure_cache_wrapper()
     async def get_data_since(
-        self, change_id: int, max_change_id: int = -1
-    ) -> Tuple[Dict[str, List[bytes]], List[str]]:
+        self, change_id: int
+    ) -> Tuple[int, Dict[str, List[bytes]], List[str]]:
         """
         Returns all elements since a change_id (included) and until the max_change_id (included).
 
         The returend value is a two element tuple. The first value is a dict the elements where
-        the key is the collection_string and the value a list of (json-) encoded elements. The
+        the key is the collection and the value a list of (json-) encoded elements. The
         second element is a list of element_ids, that have been deleted since the change_id.
         """
         changed_elements: Dict[str, List[bytes]] = defaultdict(list)
         deleted_elements: List[str] = []
 
-        # Convert max_change_id to a string. If its negative, use the string '+inf'
-        redis_max_change_id = "+inf" if max_change_id < 0 else str(max_change_id)
         # lua script that returns gets all element_ids from change_id_cache_key
         # and then uses each element_id on full_data or restricted_data.
         # It returns a list where the odd values are the change_id and the
@@ -348,22 +447,23 @@ class RedisCacheProvider:
             self.eval(
                 "get_data_since",
                 keys=[self.full_data_cache_key, self.change_id_cache_key],
-                args=[change_id, redis_max_change_id],
+                args=[change_id],
                 read_only=True,
             )
         )
 
+        max_change_id = int(elements[b"max_change_id"].decode())  # type: ignore
         for element_id, element_json in elements.items():
-            if element_id.startswith(b"_config"):
+            if element_id.startswith(b"_config") or element_id == b"max_change_id":
                 # Ignore config values from the change_id cache key
                 continue
             if element_json is None:
                 # The element is not in the cache. It has to be deleted.
                 deleted_elements.append(element_id.decode())
             else:
-                collection_string, id = split_element_id(element_id)
-                changed_elements[collection_string].append(element_json)
-        return changed_elements, deleted_elements
+                collection, id = split_element_id(element_id)
+                changed_elements[collection].append(element_json)
+        return max_change_id, changed_elements, deleted_elements
 
     @ensure_cache_wrapper()
     async def get_current_change_id(self) -> int:
@@ -435,14 +535,24 @@ class RedisCacheProvider:
 
         async with get_connection(read_only=read_only) as redis:
             try:
-                return await redis.evalsha(hash, keys, args)
+                result = await redis.evalsha(hash, keys, args)
             except aioredis.errors.ReplyError as e:
                 if str(e).startswith("NOSCRIPT"):
-                    return await self._eval(redis, script_name, keys=keys, args=args)
+                    result = await self._eval(redis, script_name, keys=keys, args=args)
                 elif str(e) == "cache_reset":
                     raise CacheReset()
                 else:
                     raise e
+            if not read_only and read_only_redis_amount_replicas is not None:
+                reported_amount = await redis.wait(
+                    read_only_redis_amount_replicas, read_only_redis_wait_timeout
+                )
+                if reported_amount != read_only_redis_amount_replicas:
+                    logger.warn(
+                        f"WAIT reported {reported_amount} replicas of {read_only_redis_amount_replicas} "
+                        + f"requested after {read_only_redis_wait_timeout} ms!"
+                    )
+            return result
 
     async def _eval(
         self, redis: Any, script_name: str, keys: List[str] = [], args: List[Any] = []
@@ -492,12 +602,20 @@ class MemoryCacheProvider:
         self.full_data = data
         self.default_change_id = default_change_id
 
+    async def add_to_full_data(self, data: Dict[str, str]) -> None:
+        self.full_data.update(data)
+
     async def data_exists(self) -> bool:
         return bool(self.full_data) and self.default_change_id >= 0
 
     async def get_all_data(self) -> Dict[bytes, bytes]:
         return str_dict_to_bytes(self.full_data)
 
+    async def get_all_data_with_max_change_id(self) -> Tuple[int, Dict[bytes, bytes]]:
+        all_data = await self.get_all_data()
+        max_change_id = await self.get_current_change_id()
+        return max_change_id, all_data
+
     async def get_collection_data(self, collection: str) -> Dict[int, bytes]:
         out = {}
         query = f"{collection}:"
@@ -538,16 +656,14 @@ class MemoryCacheProvider:
         return change_id
 
     async def get_data_since(
-        self, change_id: int, max_change_id: int = -1
-    ) -> Tuple[Dict[str, List[bytes]], List[str]]:
+        self, change_id: int
+    ) -> Tuple[int, Dict[str, List[bytes]], List[str]]:
         changed_elements: Dict[str, List[bytes]] = defaultdict(list)
         deleted_elements: List[str] = []
 
         all_element_ids: Set[str] = set()
         for data_change_id, element_ids in self.change_id_data.items():
-            if data_change_id >= change_id and (
-                max_change_id == -1 or data_change_id <= max_change_id
-            ):
+            if data_change_id >= change_id:
                 all_element_ids.update(element_ids)
 
         for element_id in all_element_ids:
@@ -555,9 +671,10 @@ class MemoryCacheProvider:
             if element_json is None:
                 deleted_elements.append(element_id)
             else:
-                collection_string, id = split_element_id(element_id)
-                changed_elements[collection_string].append(element_json.encode())
-        return changed_elements, deleted_elements
+                collection, id = split_element_id(element_id)
+                changed_elements[collection].append(element_json.encode())
+        max_change_id = await self.get_current_change_id()
+        return (max_change_id, changed_elements, deleted_elements)
 
     async def get_current_change_id(self) -> int:
         if self.change_id_data:
