@@ -1,7 +1,7 @@
 import random
 import re
 import string
-from typing import Dict, Generator, Optional, Tuple, Type, Union
+from typing import Any, Dict, Generator, Optional, Tuple, Type, Union
 
 import roman
 from django.apps import apps
@@ -64,6 +64,28 @@ def str_dict_to_bytes(str_dict: Dict[str, str]) -> Dict[bytes, bytes]:
     return out
 
 
+def is_int(obj: Any) -> bool:
+    try:
+        int(obj)
+        return True
+    except (ValueError, TypeError):
+        return False
+
+
+def is_iterable(obj: Any) -> bool:
+    """
+    Do not rely on `isinstance(obj, Iterable` with `Iterable` being imperted
+    from typing. This breaks at proxyobjects, like SimpleLazyObjects from Django.
+    Instead try to get the iterable from the object. THis fails on non-iterable
+    proxyobjects.
+    """
+    try:
+        iter(obj)
+        return True
+    except TypeError:
+        return False
+
+
 _models_to_collection_string: Dict[str, Type[Model]] = {}
 
 
